bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 20. Aventiure
___________________________________________________ #### Auentv wie der chvnic Ezele nah froen Ch' ze Wormze #### sinen boten <sande>
| ### <Daz> geschach in den geciten do froe Helche erstarp ### vn– daz der chunic Ezele ein ander wip warp ### do rieten sine frivnde in Buregonden lant ### zeiner werden witewen div froe Chriemh' genant ### Sit daz erstorben ware der schoenen Helchen lip ### si sprachen welt ir immer gewinnen edel wip ### die hoehsten un– die besten die ie kunich gewan ### so nemt die selben witewen der starche Sivrit was ir man
###### 1168 | ### Do sprach der chunich riche wie chunde daz ergan ### sit ich bin ein heiden vnt tovfes nine han ### so ist div frowe christen vn– tvot es lihte niht ### ez mvoz sin ein wnder ob ez immer geschiht
###### 1169 | ### Do sprachen aber die snellen waz ob siz lihte tvot ### durch iwern namen den hohen vn– iwer michel gvot ### so sol manz doch versvochen an daz vil edel wip ### so mvgt ir gerne minnen den ir vil wnneklichen lip
| ### Do sprach der kunic Ezele wem ist under iv bechant ### bi Rine aller beste lvte vn– ovch daz lant ### do sprach von Bechelaren der gvte Rudeger ### ich han irkant von kinde die edeln kuniginne her
###### 1171 | ### Gunthern vn– Gernoten die chunen ritter gvot ### Giselher der iunge ir ieslicher tvot ### swaz er der hohen eren mit tvgenden mac began ### ovch hant ir alten mage al daz selbe her getan
###### 1172 | ### Do sprach der kunich riche frivnt dv solt mir sagn ### ob si ob minen landen chrone solde tragn ### ist ir lip so schoene so man mir hat geseit ### des antwrt im Rvdeger der reche chve[45r]ne vn– gemeit
###### 1173 | ### Si gelichet sich mit schoene wol der frowen min ### Helchen der vil richen vn– chunde niht gesin ### in dirre werlde schoner deheines kvniges wip ### den si lobt ze frivnde der mac wol trosten den lip
| ### Er sprach so wirbez Rvdeger so lieb als ich dir si ### vn– sol ich Chriemh' immer geligen bi ### des wil ich dir lonen so ich beste chan ### so hastv minen willen mit grozen triwen getan
###### 1175 | ### Vzer miner chameren so heiz ich dir gebn ### daz dv vn– dine geverten vroliche mvgt lebn ### von chleidern von rossen des nime swaz dv wil ### des gib ich dir zware zv der boteschefte vil
###### 1176 | ### Des antwrte Rvdeger der marcgrave rich ### gert ich dines gvotes daz ware vnlobelich ### ich wil din bote gerne wesn an den Rin ### mit min selbes gvote des soltv gar ane angest sin
###### 1177 | ### Do sprach der kunic Ezele nv wenne welt ir varn ### nach der vil minneklichen got sol ivch bewarn ### der reise an allen eren vn– ovch die frowen min ### des helfe mir gelucke daz si vns genedic <mvze> sin
| ### Do sprach aber Rvdeger ê ich rvme dizze lant ### wir mvzin ê bereiten waffen un– gewant ### schilde vn– sætele des wir ere han ### ich wil ze Rine fveren fvnf hundert miner chuonen man
###### 1179 | ### Swa man in vremden landen <mih> un– die mine sehe ### daz ir ieslicher denne dir des iehe ### daz nie kunic deheiner also manigen man ### so verre baz gesande danne dv ze <Rine> habst getan
###### 1180 | ### Ob duz kunich riche dar vmbe niht wellest lan ### si was ir edeln minne Sivride vndertan ### dem Sigemundes kinde den hastv hie gesehn ### man mvse im grozer eren mit rehter warheite iehn
###### 1181 | ### Dar vmbe ich si niht vremde was si des rechen wip ### ia was wol also tivre sin vil edel lip ### daz ich niht versmahen die kuniginne sol ### durch ir grozen schone so gevellet si mir wol
| ### So wil ich iv die wareheit sprach Rvdeger do sagn ### daz wir hinnen riten in vier vn– zweinzich tagen ### ich enbivt ez Gotelinde der vil lieben frowen min ### daz ich nach Chriemh' selbe bote welle sin
###### 1183 | ### Hin ze Bechelaren sande Rvdeger ### boten sime wibe der marcravinne her ### vn– enbot ir daz er solde dem kunige werbn wip ### si gedahte frivntliche an der gvten Helchen lip
###### 1184 | ### Do div marcgrauinne die boteschaft vernam ### der mære si sich frevte doch weinens si gezam ### ob si gewinnen solde noch frowen alsam ê ### so si gedaht an Helchen daz tet Gotlinde we
| ### Vzer Hunin lande der marcgrave reit ### des was der kunich Ezele vro vn– ovch gemeit ### da zer stat ze Wiene bereite man [45v]in wat ### die er fvren solde als man vns gesagt hat
###### 1186 | ### Da ze Bechelaren im warte Gotelint ### div ivnge marcgrauinne daz Rudegeres kint ### sah ir vater gerne vn– ovch sine man ### do wart ein liebez biten von schonen kinden getan
###### 1187 | ### Do der marcgrave ze Bechelaren reit ### do was in mit vlize ir gewefen vn– ir kleit ### bereitet gar ze wnsche im un– sinen man ### ir sovmer vf der straze sah man mit in zogen dan
###### 1188 | ### Do si ze Bechelaren chomen in die stat ### disinen reisgesellen herebergen bat ### der wirt vil minneklichen vn– schvof in gvot gemach ### Gotelint div riche den wirt si niht zvngerne sach
###### 1189 | ### Sam tet sin liebiv tohter div ivnge marcgravin ### div enchunde ir vater chvnfte niht hohers mvotes sin ### die von Hvnen landen wie gerne si die sach ### mit laehendem mvnde div sveze iunchfrowe sprach
| ### Nv si vns groze willechomen min vater un– sine man ### do wart vil groze danchen mit vlize getan ### des marcgraven kinde von manigem rechen gvot ### vil wol erchande Gotelint des gvten Rvdegeres mvot
###### 1191 | ### Do si des nahtes nahen bi Rvdegere lach ### vil minnekliche vragen in div frowe pflach ### war in gesendet hete der kunic von Hvnin lant ### er sprach min liebiv frowe daz sol werden dir bechant
###### 1192 | ### Ich sol minne herren werben vmbe ein wip ### sit daz ist erstorben miner frowen lip ### ich wil nach Chriemh' riten an den Rin ### div sol hie zen Hvnen gewaltech kuniginne sin
| ### Daz wolde got sprach Goetelint moht uns daz heil geschehn ### sit daz wir ir hoeren so grozer eren iehen ### si ergazt uns miner frowen liht in alten tagen ### mit ir hohen tvgenden daz wir mvsin si verchlagen
| ### Do sprach der marcgrave trutinne min ### di mit mir svln riten hinnen an den Rin ### den sult ir frivntliche bieten iwer gvot ### so helde varent riche so sint vroelich gemvot
###### 1195 | ### Si sprach ez ist deheiner derz von mir gerne nimt ### ine geb ir ieselichem swaz im wol gezimt ### e daz ir hinnen scheidet mit den iwern man ### daz si dem wirte lobte daz wart mit vlize getan
###### 1196 | ### Hey waz man do von kamere der richen pfellil trvoch ### der wart mit den rechen geteilet do genvoch ### erfvllet vlizekliche vonn halse vnz vf den sporn ### die im da zvo behageten die het im Rvdeger erchorn
| ### An dem sibnden morgen von Bechelaren reit ### der wirt mit sinen degenen wafen vn– chleit ### furten si den vollen dvrch der Baier lant ### si wrden vf der strazen dvrch rovben selten an gerant
###### 1198 | ### Da die helede fvoren niemen niht in nam ### man moeht in dannen die[46r]nen als im wol gezam ### ritter un– knehte die waren wol gechleit ### der gvte marcgraue alsvs von Bechelaren reit
###### 1199 | ### Inre tagen zwelfen si chomen an den Rin ### done chunden disiv mære niht verholn sin ### man sagte dem chunige vn– ovch sinen man ### da chomen hohe geste der wirt do vragen began
###### 1200 | ### ob iemen si bechande daz manz im solde sagn ### man sah ir sovmere so rehte swære tragn ### daz si vil riche wæren daz wart da wol bechant ### man hiez si herbergen da ze Wormez al zehant
###### 1201 | ### Do die geste waren zen herebergen chomen ### do wart ir gevertes vaste war genomen ### si wndert wannen fveren die rechen an den Rin ### der wirt nach Hagene sande ob ez im chundich mohte sin
| ### Do sprach der von Tronege nv lat mich si sehn ### als ich si nv geschowe ich chan iv wol veriehn ### von swannen si gesendet sin in dizze lant ### si svln sin vil vremden ine habe si schiere bekant
###### 1203 | ### Inlende heten die geste nv genomen ### in vil richiv chleider was der bote chomen ### mit sinen hergesellen ze hove si do riten ### si fvrten gvtiv chleider wol vn– spæhe gesniten
###### 1204 | ### Do sprach der snelle Hagene als ich mich chan verstan ### wande ich die helde lange niht gesehn han ### si varnt dem geliche als ez si Rvdeger ### von hunischen richen der degn chvne vn– her
###### 1205 | ### Wie solde ich des getrowen sprach der chunich zehant ### daz der von Bechelaren choeme in dizze lant ### e daz <der> chunich riche die rede vol sprach ### Hagene der chvene den gvten Rvdegern sach
| ### Mit sinen besten frivndem lief er zv zim dan ### man sach fvnfhundert degene von den rossen stan ### do wrden wol enpfangen die von Hvnin lannt ### boten nie getrvgen also herlich gewant
###### 1207 | ### Do sprach in hoher stimme der herre Hagene ### nv sin groze willechomen dise degene ### der vogt von Bechelaren un– alle sine man ### daz grvzen wart mit eren den snellen Hvnin getan
###### 1208 | ### Des kuniges nehsten mage chomen da man si sach ### Ortwin von Mezzin zv Rvdegere sprach ### wir habn in aller wile mere nie gesehn ### geste hie so gerne des wil ich wærliche iehn
###### 1209 | ### Des grvzes si do danchten den helden vber al ### mit dem hergesinde si giengen in den sal ### da si den kunich fvnden bi nnanigem chvnen man ### der wirt do von dem sedele gie gegen Rvdegere dan
| ### Wie rehte frivntliche er den gast enpfie ### vn– alle sine degene Gernot do niht enlie ### ern enpfienge in ovch mit eren vn– alle sine man ### der chunic Rvdegere fvrte bi der hende dan
###### 1211 | ### Er braht in zv dem sedele da er selbe saz ### den gesten hiez man schenchen mit willen tet man daz ### mete den vil gvten vn– den besten win ### den iemen uin[46v]den chvnde in dem lande al vmben Rin
###### 1212 | ### Giselher vn– Gere die bede warn komen ### Danchwart vn– Volker die lneten wol vernomen ### von den werden gesten si wæren hochgemvot ### si enpfiengen vor dem kunige die ritter edel vnde gvot
###### 1213 | ### Do sprach zvo sime herren der degen Hagene ### ez solden immer dienen alle iwer degene ### daz vns der marcgrave ze liebe hat getan ### des solde man enpfahen wol den Gotelinde man
###### 1214 | ### Do sprach der kunic Gvnther ine chan niht langer dagn ### wie si sich gehaben beide daz svlt ir mir sagn ### Ezele vn– Helche vzer Hvnin lant ### do sprach der marcgraue ich solz iv sagn hie zehant
| ### Do stvnt er von dem sedele mit allen sinen man ### er sprach zv dem chunige lat mih vrlovp han ### ze sagene solhiv mære dar vmbe ich bin gesant ### von deme chunic Ezele her zv der Buregonden lant
###### 1216 | ### Er sprach swaz man vns mære bi iv enboten hat ### div erlovb ich iv ze sagene ane frivnde rat ### ir svlt si lazen hoeren mich vn– mine man ### wande ich iv aller eren hie ze werbene gan
###### 1217 | ### Do sprach der bote here iv enbivtet an den Rin ### getriwelichen dienest der groze voget min ### vn– allen iwern frivnden die ir mvget han ### vnde wizzet disiv boteschaft ist in triwen gar getan
###### 1218 | ### Iv bat der chunic edele chlagen sine not ### siniv lant sint verweiset min frowe div ist tot ### Helche div vil riche ein kuniginne her ### nach der min herre lidet daz wizzet vngefuogiv ser
###### 1219 | ### Kint der edeln fvrsten div si gezogen hat ### dar an ez inme lande vil iæmerlichen stat ### die enhant nv leider niemen der ir mit triwen pflege ### des wen ovch sich vil <seine> des kuniges sorge gelege
| ### Nv lon im got sprach Gunther daz er den dienest sin ### so willechlich enbvtet mir un– den frivnden min ### sinen grvoz ich gerne hie vernomen han ### den mir enbivtet Ezele des sol er groz genade han
###### 1221 | ### Do sprach von Burgonden der herre Gernot ### die werlt mac wol riwen der schonen Helchen tot ### dvrch ir manige tvgende der si wol chunde pflegn ### der rede gestvnt im Hagene der vil zierliche degn
###### 1222 | ### Do sprach aber Rvdeger der edel bote her ### sit ir mir chunic erlovbet ich sol iv sagen mer ### waz iv min lieber herre her enboten hat ### sit im nach miner frowen sin dinch so chumberlichen stat
###### 1223 | ### Man sagt mime herren iwer swester si ane man ### Sivrit si erstorben ist daz also getan ### so sol min frov Chriemh' die richen chrone tragn ### vor den Ezelen rechen diz bat iv der chunic sagn
###### 1224 | ### Do sprach der chunic riche wol gezogen was sin mvot ### so hoeret minen willen ob siz gerne tvot ### den wil ich iv chunden in disen siben [47r]tagen ### ê ihz an ir erfvere zwiv solde ich Ezelen versagn
| ### Die wile man den gesten hiez schaffen <gvot> gemach ### in wart da so gedienet daz Rvdeger des iach ### daz er da frivnde hæte bi Guntheres man ### Hagene im diente gerne er hete im alsam getan
###### 1226 | ### Alsvs beleip do Rvdeger vnz an den vierden tac ### der kunich nach rate sande wie wiselich er pflach ### vragen sine mage ob si dvhte gvot getan ### daz Chriemh' nemen solde den chunich Ezelen ze man
###### 1227 | ### Si rietenz al gemeine wan eine Hagene ### der sprach ze Gunthere dem degene ### habt ir rehte sinne so wirt ez wol behvot ### ob sis ioch volgen wolde daz irz nimmer getvot
###### 1228 | ### Warvmbe sprach do Gunther solde ihs volgen niht ### swaz der kuniginne liebes geschiht ### des sol ich ir wol gvnnen si ist div swester min ### wir soldenz selbe werben ob ez ir ere mohte sin
| ### Do sprach aber Hagene nv lat die rede stan ### vn– het ir Ezelen chunde als ich sin chvnde han ### solte si in danne minnen als ich ivch hoere iehn ### so wære iv aller erste von schulden sorgen geschehn
###### 1230 | ### Warumbe sprach do Gvnther ich behvete wol immer daz ### daz ich im chome so nahen daz ich deheinen haz ### von im mvese dvlden vn– wrde si sin wip ### do sprach aber Hagene ez gerætet nimmer min lip
###### 1231 | ### Man hiez nah Gernote vn– Giselhere gan ### ob der frowen brveder dvhte gvote getan ### daz Chriemhilt neme solde den richen chunic her ### noch widerreit ez Hagene vn– ander niemen mer
###### 1232 | ### Do sprach von Burgonden Giselher der degn ### nv mvgt ir frivnt Hagene noch der triwen pflegn ### ergetzet si der leide vn– ir ir habt getan ### swar an ir wol gelunge daz solt ir vngevehet lan
###### 1233 | ### Ia habt ir miner swester getan so starchiv leit ### so sprach aber Giselher der degn vil gemeit ### daz si des hete schulde ob si iv wære gram ### nie man deheiner frowen mere frevden noch genam
###### 1234 | ### Daz ich da wol bechenne daz tvn ich iv chvnt ### sol si nemen Ezele gelebt si an die stvnt ### si getvot uns leide swie siz getraget an ### ia gewinnet si ze dienste daz wizzet manigen chvenen man
###### 1235 | ### Des antwrt Hagene der herre Gernot ### ez mag also beliben vnz an ir beider tot ### daz wir geriten immer in Ezelen lant ### wir svln ir leisten triwe daz ist zen eren vns gewant
###### 1236 | ### Do sprach aber Hagene mir chan niemen widersagn ### vn– sol div frowe Chriemh' Helchen chrone tragn ### si getvot vns leide swie si gefvget daz ### ir svlt ez lan beliben daz chvmt iv rechen michel baz
###### 1237 | ### Mit zorne sprach do Giselher der edeln Voten svon ### wir ensvlen niht alle meinliche tvn ### swaz liebes ir geschêhe vro solten wir des sin ### swaz ir geredet Hagne ich diene ir durch die triwe min
###### 1238 | ### Do daz Hagene horte do wart er vngemvot ### Gernot vn– Giselher die stolzen ritter gvot ### vn– Gunther der riche gerieten sider daz ### ob siz loben wolde daz siz liezen ane haz
| ### Do sprach der chvene Gere so wil ich hine gan ### vn– wil mine frowen die rede wizzen lan ### waz ir der kunich Ezele her enboten hat ### ob si in nemen welle daz si mit triwen vnser rat
###### 1240 | ### Do gie der snelle reche da er Chriemh' sach ### si enpfie in minnekliche wie balde er do sprach ### ir mvgt mich gerne grvzen vn– gebn botenprot ### ivch wil gelucke scheiden vzir aller iwer not
###### 1241 | ### Ez hat durch iwer minne frowe her gesant ### ein der aller beste der ie kuniges lant ### besaz mit vollen eren oder chrone solde tragn ### ez werbent boten edele daz hiezen iv die kunige sagn
###### 1242 | ### Do sprach div iamers riche iv sol verbieten got ### vn– andern minen frivnden daz si deheinen spot ### an mir armen vben waz soldich einem man ### der ie hercen liebe von gvtem wibe gewan
###### 1243 | ### Si widerreit iz sere do chomen aber sint ### Gernot ir brvoder vn– Giselher daz kint ### di baten minnekliche trosten si den mvot ### ob si den chunic næme ez wær ir wærlichen gvot
| ### Vberwinden niemen chunde do daz wip ### daz si minnen wolde deheines mannes lip ### do baten si die rechen nv lazet doch geschehn ### ob er niht anders wellet tvon so svlt ir Rvdegeren sehn
###### 1245 | ### Daz enwil ich niht versprechen ine welle in gerne sehn ### den gvten Rvdegeren daz laz ich wol geschehn ### dvrch sine manige tvgende wær er niht her gesant ### swerz ander boten wæren den wær ich immer vnbechant
###### 1246 | ### Si sprach ir svlt in morgen heizen her gan ### zv miner chemenaten ich wil in hoeren lan ### wes ich mich habe beraten wil ich im denne sagn ### ir wart eriteniwet daz ir vil groezlich chlagn
###### 1247 | ### Do engert ovch nihtes mere der edel Rvdegere ### niwan daz er gesæhe die kuniginne here ### er wiste sich so wisen daz er wol an getragen ### mohte swaz er wolde ir rede im mvose wol behagen
| ### Des andern morgens do man frvemesse sanch ### die edeln boten chomen do wart da groz gedranch ### die mit Rvdegere ze lnofe solden gan ### der sach man wol gekleidet manigen wætlichen man
###### 1249 | ### Chriemh' div vil arme div trvrich gemvot ### si warte Rvdegere dem edeln boten gvot ### der vant si in der wæte die si alle cite trvch ### da bi het ir gesinde richer chleider genvoch
###### 1250 | ### Si gie in hin begegene zvo der tvere stan ### vn– empfie vil liepliche den Ezelen man ### niwan mit zwelf gesellen man in dar in verlie ### man bot im michel ere ir chom ein hoher bote nie
###### 1251 | ### Man bat den herren sizzen vn– sine man ### die zwene marcgraven sach man [48r]vor in stan ### Gern vn– Ecgewarten daz schvof div kuniginne ### die selben boten chunden nimmer baz gewirdet sin
| ### Do si da wol gesazen vn– sahn manich wip ### do pflach niwan weinens der Chriemh' lip ### ir <wat> was vor <den> brusten der heizen træhene naz ### daz sach der marcgrave der helt niht langer do da saz
###### 1253 | ### Er sprach in grozen zvhten vil edel kuniges chint ### mir vn– minen geverten di mit mir chomen sint ### svlt ir frow erlovben daz wir <fvr> ivch stan ### vn– sagen iv div mære durch waz wir her geriten han
###### 1254 | ### Nv si iv erlovbet sprach div kunigin ### ze sagen iwer mære also stat min sin ### sprechet swaz ir wellet des ivch dunche gvot ### di boten an ir wol sahen ir vil trvrigen mvot
###### 1255 | ### Do sprach von Bechelaren der fvrste Rvdeger ### dienst un– triwe Ezel ein kunic her ### hat iv enboten frowe her in dizze lant ### er hat nach iwer minne vil gvte degene gesant
###### 1256 | ### Vn– enbivtet iv innekliche frevde ane leit ### der stæten frivntschefte si er iv bereit ### als Helchen miner frowen div im ze hercen lach ### ir sult nv tragen chrone der min frowe wilen pflach
| ### Do sprach div kuniginne vil edel Rvdeger ### wær ieman der bechande div minen scharpfen ser ### der riete mir niht trvten noch deheinen man ### wan ich vlos ein den besten den ie frowe mer gewan
###### 1258 | ### Waz mag ergezzen leides sprach do der chvne man ### wan vrivntliche liebe swer die chan began ### vn– dann der einen chivset der im ze rehte chvmet ### fvr hercenliche swære niht so grozliche frvmet
###### 1259 | ### Vn– rvchet ir ze minnen den hohen voget min ### zwelf richer chrone svlt ir frowe sin ### dar zv git iv min herre wol drizech fvrsten lant ### div hat er betwngen mit siner ellenthaften hant
###### 1260 | ### Ir svlt ovch werden frowe vber manigen chvnen man ### die ovch miner frowen waren vndertan ### vn– vil der schonen mægede der si hete gewalt ### vn– hoher rechen magen edel <chven> vn– balt
###### 1261 | ### Darzv iv min <herre> git daz heizet er iv sagen ### ob ir gervchet chrone bi dem chunige tragen ### gewalt den aller hohsten den Helche ie gewan ### den svlt ir gewaldechliche han ob allen sinen man
| ### Do sprach div kuniginne wie mohte minen lip ### immer des gelvsten deich wrde heledes wip ### mir hat der tot an einem so rehte leit getan ### des ich vnz an min ende mvz in riwen immer stan
###### 1263 | ### Do sprachen aber die Hvnin kuniginne rich ### iwer leben wirt bi Ezele so rehte lobelich ### daz ir des wol vergezzet ist daz ez ergat ### wan der kunic riche vil manigen zieren degen hat
###### 1264 | ### Die miner frowen mægede vn– iwer mægedin ### svln die [48a]bi ein ander ein gesinde sin ### da bi so mohten rechen werden wol gemvot ### lat ez iv frowe raten ez wirt iv werlichen gvot
###### 1265 | ### Si sprach in ir zvehten nv lat die rede stan ### vnze morgen frveie so svlt ir her gan ### so wil ich iv antwrten des ir da habet mvot ### des mvsen do gevolgen die rechen chvne un– gvot
| ### Do si zen herbergen alle chomen dan ### do hiez div frowe Chriemh' nach <Giselhere> gan ### vn– ovch nach ir mvoter si saget in beiden daz ### daz si gezæme weinen vn– niht anders baz
###### 1267 | ### Do sprach ir brvoder Giselher swester mir ist geseit ### vn– wilz ovch gelovben wol daz elliv diniv leit ### Ezel der chunic swende vn– nimstv in ze man ### swaz ander iemen rate so dunchet ez mich gvot getan
###### 1268 | ### Er mac dich wol ergezzen sprach aber Giselher ### vonme Roten zv dem Rine vf bi Elbe vnz an daz mer ### so ist ir deheiner also gewaltich niht ### dv maht dich frevn balde sor din ze kuniginne giht
###### 1269 | ### Si sprach zvo zir brvder zwiv rætestv mir daz ### chlagen un– weinen mir immer zæme baz ### wie solde ich vor rechen da ze hove gan ### wart min lip ie schone des bin ich ane getan
###### 1270 | ### Vote ir beider mvoter sprach ir tohter zvo ### swaz dine brveder raten vil liebez chint daz tvo ### nv volge dinen frivnden so mach dir wol geschehen ### ich han dich doch so lange in grozem leide gesehn
| ### Do bat si got den riche fvgen ir den rat ### daz si ze gebene hete golt <silber> vn– wat ### sam bi ir ersten manne do der noch was gesvnt ### si gelebte doch nimmer mere sit so vroliche stvnt
###### 1272 | ### Do gedahtes in ir sinne sol ich minen lip ### gebn einem heiden ich bin ein christen wip ### des mvse ich von der werlde groz itewize han ### gêb er mir elliv riche so ist ez immer vngetan
###### 1273 | ### Da mite siz lie beliben die naht unz an den tac ### div frowe in vil gedanchen an ir bette lac ### div ir vil liehten ovgen wrden trvchen nie ### vnze si aber den morgen hin zer mettine gie
###### 1274 | ### Ze rehter messecite die herren waren chomen ### si heten aber ir swester vnder hende genomen ### ia rieten si ir minnen den chunic vz Hvnen lant ### die frowen ir deheiner vil luzzil vroliche vant
| ### Si baten dar gewinnen die Ezelen man ### Rvdeger der riche biten do began ### die frowen minnekliche waz si nv wolde tvon ### ob si ze manne wolde des kunic Botelunges svon
###### 1276 | ### Si iach daz si geminnen nimmer mere wolde man ### do sprach der marcgrave daz wære missetan ### zwiv woldet ir verderben also sconen lip ### ir mvget noch mit eren werden hohes rechen wip
###### 1277 | ### Niht half daz si gebaten vnze Rvdeger ### sprach in heinliche die kuniginne her [49r] ### er wolde si ergezzen swaz ir ie geschach ### ein teil begundir senften ir vil vnsenftez vngemach
###### 1278 | ### Er sprach frowe here lat iwer <weinen> ### ob ir zen Hvnin hetent niemens danne min ### getriwer miner frivnde vn– ovch der minen marn ### er mveses sere engelten vn– het iv iemen iht getan
| ### Da von ein teil geringet wart do der frowen mvot ### si sprach so swert mir Rvdeger swaz mir iemen tvot ### daz ir mir sit der næhste der reche miniv leit ### do sprach der marcgrave des bin ich frowe bereit
###### 1280 | ### Mit allen sinen mannen swor ir do Rvdeger ### mit triwen immer dienen vn– daz die rechen her ### ir nimmer niht versageten vz Ezelen lant ### des si ere habn solde des sichert ir Rvdegeres hant
###### 1281 | ### Do gedahte div getriwe sit daz ich frivnde han ### also vil gewnnen nv sol ich reden lan ### die lvte swaz si wellen ich iamerhaftez wip ### waz ob noch wirt errochen mins vil lieben mannes lip
###### 1282 | ### Si gedahte sit daz Ezele der rechen hat so vil ### sol ich den gebieten so tvn ich swaz ich wil ### er ist ovch wol so riche daz ich ze gebene han ### mich hat der mordær Hagene des minen ane gar getan
| ### Si sprach ze Rvedegere het ich daz vernomen ### daz er niht wære ein heiden so wolde ich gerne chomen ### swar er hete willen vn– næme in zeinem man ### do sprach der marcgrave die rede svlt ir frowe lan
###### 1284 | ### Ern ist niht gar ein heiden des svlt ir sicher sin ### ia was vil wol becheret der liebe herre min ### wan daz er sich widere vernogieret hat ### wolt ir <in> frowe minnen so mohte sin noch werden rat
###### 1285 | ### Ovch hat er so vil rechen in christenlicher ê ### daz iv bi dem kunige nimmer wirdet we ### ir mvegt ovch lihte erwerben daz der fverste gvot ### wider ze gote wendet beide sele vn– mvot
| ### Do sprachen aber ir brveder lobt ir swester min ### iwer vngemvete svlt ir nv lazen sin ### si gertens also lange daz ir vil trvrich lip ### lobte vor den degenen si wrde Ezelen wip
###### 1287 | ### Si sprach ich mvz iv volgen ir armiv kunigin ### daz ih var zen Hvnin so daz nv mac gesin ### swenne ich die frivnt gewinne die mich fvren in sin lant ### des bot div kuniginne vor den degn ir hant
###### 1288 | ### Do sprach der marcgrave habt ir zwene man ### dar zvo han ich ir mere ez wirdet wol getan ### daz wir ivch mit den eren bringen vber Rin ### ine laze ivch nv niht langer hie zen Buregonden sin
###### 1289 | ### Fvnf hundert miner manne vn– ovch der mage min ### die svln iv hie dienen vn– ovch da heime sin ### swie ir in gebietet ich selbe tvon alsam ### so ir mich ermant der mære daz ihs nimmer mich gescham
| ### Nv heizet iv bereiten iwer pferitchleit ### die Rvdegeres ræte iv nimmer werdent leit ### vn– sagetez iwern mægeden die ir da fvren welt ### ia chumet vns begegene <vil> manic vz erwelter [49v]helt
###### 1291 | ### Si heten noch gesmide daz man da vor reit ### bi Sivrides ziten daz si vil manige meit ### mit eren mohten fvren so si wolden dan ### hey waz man gvter sætele den schonen frowen gewan
###### 1292 | ### Ob si da vor getrvgen deheiniv richen chleit ### der wart in zv der verte vil manigez nv bereit ### wande in von dem chunige so vil gesaget wart ### si slvzzen vf die kisten die ê stunden wol bespart
###### 1293 | ### Si heten groz vnmvoze vnz an den zwelften tac ### si svochten vz den valden des vil dar inne lach ### Chriemh' hiez entsliezen balde ir chameren dan ### si wolde machen riche alle Rvdegeres man
| ### Si hete noch des goldes von Nibelunge lant ### si wande ez da zen Hv^nin teilen solde ir hant ### daz iz sehs hundert moere ninder chunden tragen ### div mære horte Hagene da von Chriemh' sagen
###### 1295 | ### Er sprach sit mir Chriemh' doch nimmer wirdet holt ### so mvoz ovch hie beliben daz Sivrides golt ### zwiv solde ich minen vinden lan so michel gvot ### ich wæiz wol daz div frowe wnder mit dem schazze getvot
###### 1296 | ### Vn– bræhte si in zen Hvnin ich wil gelovben daz ### er wrde doch zerteilet niwan vf minen haz ### sine habent ovch niht der rosse die in solden tragen ### in wil behalten Hagene daz sol man Chriemh' sagen
| ### Do si vernam div mære do wart ir grimme leit ### ez wart ovch den kunigen allen drin geseit ### si woldenz gerne wenden do des niht geschach ### Rvdeger der edele dar zvo herliche sprach
###### 1298 | ### Vil richiv kuniginne zwiv chlaget ir daz golt ### iv ist der chvnic Ezele in der maze holt ### gesehent ivch siniv ovgen er git iv also vil ### daz irz zerteilet nimmer des ich iv eide swern wil
###### 1299 | ### Do sprach div chvniginne vil edel Rvdeger ### ez gewan nie kuniges tohter die richeite mer ### denne der mich Hagene ane hat getan ### do chome der starche Gernot hin zer chameren gegan
###### 1300 | ### Mit gewalt des chuniges slvzzil stiez er an die tver ### golt daz Chriemh' reichte man derfver ### ze drizzech tvsint marchen oder dannoch baz ### hiez er nemen die geste liep was Gunthere daz
| ### Do sprach von Bechelaren der Gotelinde man ### ob ez min frowe Chriemh' allez moehte han ### swaz sin ie wart gefveret von Nibelunge lant ### sin gervret nimmer nnarche min noch der kuniginne hant
###### 1302 | ### Lat ez nemen frowe swerz gerne haben wil ### ich brahte vz mime lande des minen also vil ### daz wir <es> vf der straze habn gvten rat ### vn– unser choste hinnen mit vollen herlichen stat
###### 1303 | ### Da vor in aller wile erfullet zwelf schrin ### des aller besten goldes daz inder mohte sin ### heten noch ir meide daz fvrte man von dan ### mit der chuniginne daz ander [5or]mvsin si da lan
###### 1304 | ### Gewalt des vbelen Hagenen der duhte si ze starch ### si het ir opfer goldes noch wol tusint march ### daz teilte si der sele irs vil <lieben> man ### daz dvohte Rvdegere in grozen triwen getan
| ### Do sprach div frowe Chriemh' wa nv frivnde min ### die dvrch mich ellende zen Hunin wellen sin ### vn– mit mir svln riten in Ezelen lant ### die nemen golt daz mine vn– chavffen rosse vn– ovch gewant
###### 1306 | ### Des antwrte ir schiere der marcgrave Ekkewart ### sit ich iwer gesinde ie von erste wart ### so entweich ich iv nie triwen sprach der chune degn ### vn– wil iv immer dienen die wile wir beide lebn megn
###### 1307 | ### Ich wil ovch mit mir fveren hundert miner man ### der ich iv ze dienste wol mit triwen gan ### wir sin vngescheiden ez entvo der tot ### der rede neig im Chriemh' daz irz der helt so wol erbot
###### 1308 | ### Do zoh man dar die moere si wolden varn dan ### da wart vil michel weinen von frivnden getan ### frov Vote div gvote vn– manic schoene meit ### die zeigeten daz in wâre nach der kuniginne leit
###### 1309 | ### Hvndert schoner megede div frowe mit ir nam ### die wrden so gechleidet als in daz wol gezam ### vf ir vil liehten bovge die træhene vielen nider ### si gelebten vil der frevde dort bi Ezelen sider
| ### Ir brvoder chomen beide Giselher un– Gernot ### mit ir ingesinde als in ir zvht gebot ### do wolden si beleiten ir liebe swester dan ### ovch fvrten si ir degene mit in wol tvsint chune man
###### 1311 | ### Do chom der snelle Gere vn– ovch Ortewin ### Rvmolt der chuchenmeister da mite mvse sin ### si schvfen die nahtselde der frowen vf den wegn ### Volcher was ir marschalch der solde ir herberge pflegen
###### 1312 | ### Nach chussen michel weinen wart da vil vernomen ### ê daz si von der burge ze velde wærn chomen ### vz riten vn– giengen die sis niene gebat ### do reit der chunic Gunther mit ir ein wenich fver die stat
###### 1313 | ### ê si von huse fveren si heten fver gesant ### ir boten harte snelle in der Hunin lant ### die dem chvnige sageten daz im Rvdeger ### ze wibe hete gewnnen die edeln chuniginne her
###### 1314 | ### Di boten strichen sere in was der reise not ### durch die grozen ere vn– durch richiv potenbrot ### do si ze lande waren mit den mæren chomen ### do het der chunic Ezele nie so liebes niht vernomen
###### 1315 | ### Durch disiv lieben mære hiez der chunich gebn ### den boten solhe gabe daz si wol mohten lebn ### mit frevden immer mere dar nach vnze an ir tot ### mit liebe was verswnden des chuniges chumber vnde <NOT>

<<< Übersicht <<< vorige Seite nächste Seite >>>